@@ -439,7 +439,7 @@ class Test:
 # no error
 def test():
     pass
-  
+
   # Wrongly indented comment
     pass
 # end
@@ -615,13 +615,13 @@ def g():
 
 # E302
 class Test:
-	
+
 	pass
-	
+
 	def method1():
 		return 1
-		
-		
+
+
 	def method2():
 		return 22
 # end
@@ -762,7 +762,7 @@ class Test:
 def fn():
     pass
 
- 
+
     pass
 # end
 
@@ -933,3 +933,13 @@ def a():
     async def b():
         pass
 # end
+
+
+# no error
+@overload
+def arrow_strip_whitespace(obj: Table, /, *cols: str) -> Table: ...
+@overload
+def arrow_strip_whitespace(obj: Array, /, *cols: str) -> Array: ...  # type: ignore[misc]
+def arrow_strip_whitespace(obj, /, *cols):
+    ...
+# end
