@@ -18,6 +18,8 @@ index = index - 1
 a_list = a_list + ["to concat"]
 some_set = some_set | {"to concat"}
 to_multiply = to_multiply * 5
+to_multiply = 5 * to_multiply
+to_multiply = to_multiply * to_multiply
 to_divide = to_divide / 5
 to_divide = to_divide // 5
 to_cube = to_cube**3
@@ -53,3 +55,4 @@ a_list[0] = a_list[:] * 3
 index = a_number = a_number + 1
 a_number = index = a_number + 1
 index = index * index + 10
+some_string = "a very long start to the string" + some_string
