@@ -137,10 +137,6 @@ fn find_file_open<'a>(
         ..
     } = item.context_expr.as_call_expr()?;
 
-    if func.as_name_expr()?.id != "open" {
-        return None;
-    }
-
     let var = item.optional_vars.as_deref()?.as_name_expr()?;
 
     // Ignore calls with `*args` and `**kwargs`. In the exact case of `open(*filename, mode="w")`,
@@ -152,6 +148,10 @@ fn find_file_open<'a>(
         return None;
     }
 
+    if !semantic.match_builtin_expr(func, "open") {
+        return None;
+    }
+
     // Match positional arguments, get filename and mode.
     let (filename, pos_mode) = match_open_args(args)?;
 
