@@ -1,7 +1,9 @@
+use globset::Candidate;
 use ruff_linter::{
     display_settings, fs::normalize_path_to, settings::types::FilePattern,
     settings::types::PreviewMode,
 };
+use ruff_workspace::resolver::match_candidate_exclusion;
 use ruff_workspace::{
     configuration::{Configuration, FormatConfiguration, LintConfiguration, RuleSelection},
     pyproject::{find_user_settings_toml, settings_toml},
@@ -12,12 +14,13 @@ use std::{
     path::{Path, PathBuf},
     sync::Arc,
 };
-use walkdir::{DirEntry, WalkDir};
+use walkdir::WalkDir;
 
 use crate::session::settings::{ConfigurationPreference, ResolvedEditorSettings};
 
-#[derive(Default)]
 pub(crate) struct RuffSettings {
+    /// Settings used to manage file inclusion and exclusion.
+    file_resolver: ruff_workspace::FileResolverSettings,
     /// Settings to pass into the Ruff linter.
     linter: ruff_linter::settings::LinterSettings,
     /// Settings to pass into the Ruff formatter.
@@ -54,7 +57,7 @@ impl RuffSettings {
                 .ok()
             })
             .unwrap_or_else(|| {
-                let default_configuration = ruff_workspace::configuration::Configuration::default();
+                let default_configuration = Configuration::default();
                 EditorConfigurationTransformer(editor_settings, root)
                     .transform(default_configuration)
                     .into_settings(root)
@@ -64,6 +67,7 @@ impl RuffSettings {
             });
 
         RuffSettings {
+            file_resolver: fallback.file_resolver,
             formatter: fallback.formatter,
             linter: fallback.linter,
         }
@@ -82,12 +86,77 @@ impl RuffSettingsIndex {
     pub(super) fn new(root: &Path, editor_settings: &ResolvedEditorSettings) -> Self {
         let mut index = BTreeMap::default();
 
-        for directory in WalkDir::new(root)
-            .into_iter()
-            .filter_map(Result::ok)
-            .filter(|entry| entry.file_type().is_dir())
-            .map(DirEntry::into_path)
-        {
+        // Add any settings from above the workspace root.
+        for directory in root.ancestors() {
+            if let Some(pyproject) = settings_toml(directory).ok().flatten() {
+                let Ok(settings) = ruff_workspace::resolver::resolve_root_settings(
+                    &pyproject,
+                    Relativity::Parent,
+                    &EditorConfigurationTransformer(editor_settings, root),
+                ) else {
+                    continue;
+                };
+
+                index.insert(
+                    directory.to_path_buf(),
+                    Arc::new(RuffSettings {
+                        file_resolver: settings.file_resolver,
+                        linter: settings.linter,
+                        formatter: settings.formatter,
+                    }),
+                );
+                break;
+            }
+        }
+
+        // Add any settings within the workspace itself
+        let mut walker = WalkDir::new(root).into_iter();
+
+        while let Some(entry) = walker.next() {
+            let Ok(entry) = entry else {
+                continue;
+            };
+
+            // Skip non-directories.
+            if !entry.file_type().is_dir() {
+                continue;
+            }
+
+            let directory = entry.into_path();
+
+            // If the directory is excluded from the workspace, skip it.
+            if let Some(file_name) = directory.file_name() {
+                if let Some((_, settings)) = index
+                    .range(..directory.clone())
+                    .rfind(|(path, _)| directory.starts_with(path))
+                {
+                    let candidate = Candidate::new(&directory);
+                    let basename = Candidate::new(file_name);
+                    if match_candidate_exclusion(
+                        &candidate,
+                        &basename,
+                        &settings.file_resolver.exclude,
+                    ) {
+                        tracing::debug!("Ignored path via `exclude`: {}", directory.display());
+
+                        walker.skip_current_dir();
+                        continue;
+                    } else if match_candidate_exclusion(
+                        &candidate,
+                        &basename,
+                        &settings.file_resolver.extend_exclude,
+                    ) {
+                        tracing::debug!(
+                            "Ignored path via `extend-exclude`: {}",
+                            directory.display()
+                        );
+
+                        walker.skip_current_dir();
+                        continue;
+                    }
+                }
+            }
+
             if let Some(pyproject) = settings_toml(&directory).ok().flatten() {
                 let Ok(settings) = ruff_workspace::resolver::resolve_root_settings(
                     &pyproject,
@@ -99,6 +168,7 @@ impl RuffSettingsIndex {
                 index.insert(
                     directory,
                     Arc::new(RuffSettings {
+                        file_resolver: settings.file_resolver,
                         linter: settings.linter,
                         formatter: settings.formatter,
                     }),
@@ -115,8 +185,7 @@ impl RuffSettingsIndex {
         if let Some((_, settings)) = self
             .index
             .range(..document_path.to_path_buf())
-            .rev()
-            .find(|(path, _)| document_path.starts_with(path))
+            .rfind(|(path, _)| document_path.starts_with(path))
         {
             return settings.clone();
         }
